import { Module } from '@nestjs/common';
import { APP_FILTER, APP_INTERCEPTOR, APP_GUARD } from '@nestjs/core';
import { TypeOrmModule } from "@nestjs/typeorm";
import { Connection } from "typeorm";

import { AppController } from './app.controller';
import { AppService } from './app.service';
import { UserModule } from './user/user.module';

import { LoggingInterceptor } from './shared/logging.interceptor';
import { MapMarkerModule } from './mapmarkers/mapmarkers.module';

import { HttpErrorFilter } from './shared/http-error.filter';
import { RolesGuard } from './shared/roles.guard';

/*
Appmodule is the core of the system.
forRoot imports database data from ormconfig.json file
All the modules contain their respective controllers and service
*/

@Module({
  imports: [TypeOrmModule.forRoot(), UserModule, MapMarkerModule],
  controllers: [AppController],
  providers: [
    AppService, {
      provide: APP_FILTER,
      useClass: HttpErrorFilter, 
    },
    {
      provide: APP_INTERCEPTOR,
      useClass: LoggingInterceptor,
    },{
      provide: APP_GUARD,
      useClass: RolesGuard,
    }   
  ],
})
export class AppModule {
  constructor(private readonly connection: Connection) {}
}
