import { Controller, Body, Get, Put, UseGuards } from '@nestjs/common';

import { MapMarkerService } from './mapmarker.service';
import { MapMarkerDTO } from './mapmarker.dto';
import { AuthGuard } from '../shared/auth.guard';
import { User } from '../user/user.decorator';
import { Roles } from '../shared/roles.decorator';

@Controller('mapmarkers')
export class MapMarkersController {
    constructor(private mapmarkerservice: MapMarkerService){}
    
    // Insert figure location, needs "authorization" header with valid Bearer token and content-type json
    @Put('insertLocation')
    @UseGuards(new AuthGuard())
    async insertLocation(@User('id') person, @Body() data: MapMarkerDTO): Promise<string>{
        try {
            return this.mapmarkerservice.insertLocation(person, data);
        } catch (error) {
            return error;
        }
    }

    // return all markers through service
    @Get('getall')
    async getAll(){
        try{
            return this.mapmarkerservice.getAllMarkers();
        }catch(error){
            return error.message;
        }
    }

    @Get('test')
    async test(){
        try {
            return this.mapmarkerservice.test();
        } catch (error) {
            return error.message;
        }
    }
    @Get('testroles')
    @Roles('gm')
    async testroles(){
        try {
            return this.mapmarkerservice.test();
        } catch (error) {
            return error.message;
        }
    }
}
